@@ -225,12 +225,15 @@ class CreatorTabWidget(QWidget):
         # Create second tab
         gridlayout2 = QGridLayout()
         self.tab2.setLayout(gridlayout2)
+        licensegroupbox = QGridLayout()
+        self.groupboxlicense = QGroupBox()
+        self.groupboxlicense.setLayout(licensegroupbox)
         self.acceptedby = QLabel()
         self.acceptedby.setText('Accepted by:')
         self.ack = QComboBox()
         self.ack.setFixedWidth(150)
-        gridlayout2.addWidget(self.acceptedby, 0, 0)
-        gridlayout2.addWidget(self.ack, 0, 1)
+        licensegroupbox.addWidget(self.acceptedby, 0, 0)
+        licensegroupbox.addWidget(self.ack, 0, 1)
         self.ack.addItem('admin')
         self.ack.addItem('user')
         self.extlicense = QLabel()
@@ -238,8 +241,8 @@ class CreatorTabWidget(QWidget):
         self.extlicense.setFixedWidth(300)
         self.eli = QComboBox()
         self.eli.setFixedWidth(300)
-        gridlayout2.addWidget(self.extlicense, 1, 0)
-        gridlayout2.addWidget(self.eli, 1, 1)
+        licensegroupbox.addWidget(self.extlicense, 2, 0)
+        licensegroupbox.addWidget(self.eli, 2, 1)
         self.eli.addItem('GPL-2.0 (General Public License Version 2.0)')
         self.eli.addItem('GPL-3.0 (General Public License Version 3.0)')
         self.eli.addItem('LGPL-3.0 (Lesser General Public '
@@ -248,10 +251,15 @@ class CreatorTabWidget(QWidget):
                          'License Version 2.1)')
         self.eli.addItem('CC-BY-SA-4.0 (Creative Commons Attribution-'
                          'ShareAlike 4.0 International License')
+        suppressgroupbox = QGridLayout()
+        self.groupboxsuppress = QGroupBox()
+        self.groupboxsuppress.setLayout(suppressgroupbox)
         self.soupdbox = QCheckBox('suppress-on-update')
         self.sifreqbox = QCheckBox('suppress-if-required')
-        gridlayout2.addWidget(self.soupdbox, 2, 0)
-        gridlayout2.addWidget(self.sifreqbox, 3, 0)
+        suppressgroupbox.addWidget(self.soupdbox, 0, 0)
+        suppressgroupbox.addWidget(self.sifreqbox, 0, 1)
+        gridlayout2.addWidget(self.groupboxlicense, 0, 0)
+        gridlayout2.addWidget(self.groupboxsuppress, 3, 0)
 
         # Create third tab
         gridlayout3 = QGridLayout()
@@ -343,6 +351,14 @@ class CreatorTabWidget(QWidget):
         self.iconbox.setLayout(gridbox4)
         self.iconbox.setEnabled(False)
         self.iconbox.hide()
+        self.label_iconset_ziparchive = QLabel(
+            'Choose the *.zip archive for your IconSet Extension')
+        self.iconset_archive_button = QPushButton(
+            'Choose the *.zip archive')
+        self.iconset_archive_button.clicked.connect(
+            self.copy_iconset_archive)
+        gridbox4.addWidget(self.label_iconset_ziparchive, 0, 0)
+        gridbox4.addWidget(self.iconset_archive_button, 0, 1)
         self.palettebox = QGroupBox('Palette Extension')
         gridbox5 = QGridLayout()
         self.palettebox.setLayout(gridbox5)
@@ -417,17 +433,30 @@ class CreatorTabWidget(QWidget):
 
         # building manifest.xml
         manifestfile = minidom.Document()
-        manifest_manifest = manifestfile.createElement(
-            'manifest:manifest')
-        manifest_manifest.setAttribute(
-            'xmlns:manifest', 'http://openoffice.org/2001/manifest')
-        manifest_file_entry = manifestfile.createElement(
-            'manifest:file-entry')
-        manifest_file_entry.setAttribute(
-            'manifest:media-type',
-            'application/vnd.sun.star.configuration-data')
-        manifest_file_entry.setAttribute(
-            'manifest:full-path', 'paths.xcu')
+        if self.radiobuttoniconset.isChecked() is True:
+            manifest_manifest = manifestfile.createElement(
+                'm:manifest')
+            manifest_manifest.setAttribute(
+                'xmlns:manifest', 'http://openoffice.org/2001/manifest')
+            manifest_file_entry = manifestfile.createElement(
+                'm:file-entry')
+            manifest_file_entry.setAttribute(
+                'm:media-type',
+                'application/vnd.sun.star.configuration-data')
+            manifest_file_entry.setAttribute(
+                'm:full-path', 'config.xcu')
+        else:
+            manifest_manifest = manifestfile.createElement(
+                'manifest:manifest')
+            manifest_manifest.setAttribute(
+                'xmlns:manifest', 'http://openoffice.org/2001/manifest')
+            manifest_file_entry = manifestfile.createElement(
+                'manifest:file-entry')
+            manifest_file_entry.setAttribute(
+                'manifest:media-type',
+                'application/vnd.sun.star.configuration-data')
+            manifest_file_entry.setAttribute(
+                'manifest:full-path', 'paths.xcu')
         manifest_manifest.appendChild(manifest_file_entry)
         manifestfile.appendChild(manifest_manifest)
 
@@ -626,14 +655,39 @@ class CreatorTabWidget(QWidget):
 
             palette_soc_file.appendChild(tag_color_table)
 
+        # buiding the config.xcu for iconset extensions
+        if self.radiobuttoniconset.isChecked() is True:
+            iconconfigfile = minidom.Document()
+            tag_ooritems = iconconfigfile.createElement('oor:items')
+            tag_ooritems.setAttribute(
+                'xmlns:oor',
+                'http://openoffice.org/2001/registry')
+            tag_item = iconconfigfile.createElement('item')
+            tag_item.setAttribute(
+                'oor:path',
+                '/org.openoffice.Office.Paths/Paths/Iconset/InternalPath')
+            tag_node = iconconfigfile.createElement('node')
+            tag_node.setAttribute('oor:name', '%origin%/iconsets')
+            tag_node.setAttribute('oor:op', 'fuse')
+            tag_item.appendChild(tag_node)
+            tag_ooritems.appendChild(tag_item)
+            iconconfigfile.appendChild(tag_ooritems)
+
         os.makedirs(os.path.join(
             cwd, 'working_directory', extensionname,
             'META-INF'), exist_ok=True)
         os.makedirs(os.path.join(
             cwd, 'working_directory', extensionname,
             'registration'), exist_ok=True)
+
+        if self.radiobuttoniconset.isChecked() is True:
+            os.makedirs(os.path.join(
+                cwd, 'working_directory', extensionname,
+                'iconsets'), exist_ok=True)
+
         path = os.path.join(cwd, 'working_directory', extensionname)
-        licenseinputpath = os.path.join(cwd, 'license_files', licensefilename)
+        dir_license_templates = os.path.dirname(__file__)
+        licenseinputpath = os.path.join(dir_license_templates, 'license_files', licensefilename)
         licenseoutputpath = os.path.join(
             cwd, 'working_directory', extensionname, 'registration',
             licensefilename)
@@ -646,8 +700,9 @@ class CreatorTabWidget(QWidget):
         with open(os.path.join(path, 'META-INF', 'manifest.xml'), 'w') as f:
             manifestfile.writexml(f, "", "\t", "\n")
 
-        with open(os.path.join(path, 'path.xcu'), 'w') as f:
-            path_xcu_file.writexml(f, "", "\t", "\n")
+        if self.radiobuttoniconset.isChecked() is False:
+            with open(os.path.join(path, 'path.xcu'), 'w') as f:
+                path_xcu_file.writexml(f, "", "\t", "\n")
 
         if self.radiobuttonpalette.isChecked() is True:
             os.makedirs(os.path.join(
@@ -657,6 +712,10 @@ class CreatorTabWidget(QWidget):
             with open(os.path.join(path, 'palette', palettfilename), 'w') as f:
                 palette_soc_file.writexml(f, "", "\t", "\n")
 
+        if self.radiobuttoniconset.isChecked() is True:
+            with open(os.path.join(path, 'config.xcu'), 'w') as f:
+                iconconfigfile.writexml(f, "", "\t", "\n")
+
         with ZipFile(
             os.path.join(
                 cwd,
@@ -892,6 +951,26 @@ class CreatorTabWidget(QWidget):
                 cwd, 'working_directory', extensionname, 'template')
             shutil.unpack_archive(template_archivename, path)
 
+    def copy_iconset_archive(self):
+
+        '''
+        Copy the archive of the iconset to the subfolder
+        for the iconset.
+        '''
+        iconset_file_name = QFileDialog.getOpenFileName(
+            caption='Choose the iconset zip file for your '
+                    'IconSet extension',
+            filter='Archive (*.zip)'
+            )
+        if iconset_file_name:
+            os.makedirs(os.path.join(
+                cwd, 'working_directory', extensionname,
+                'iconsets'), exist_ok=True)
+            path = os.path.join(
+                cwd, 'working_directory', extensionname,
+                'iconsets')
+            shutil.copy(iconset_file_name[0], path)
+
 
 if __name__ == '__main__':
     app = QApplication(sys.argv)
